The pendent drop method
========================

This section is in construction.

It will contain a brief but clear explanation of the pendent drop method

See this article : https://openresearchsoftware.metajnl.com/articles/10.5334/jors.97